#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.1
visibility:           public
id:                   ansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm
key:                  ansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  0badb69dd7123c545ff2ec509b4c045b
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-1.1-DxOUKZZWDkOLO1YHeE631k:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm
depends:
    ansi-terminal-types-1.1-DxOUKZZWDkOLO1YHeE631k base-4.18.2.1
    colour-2.3.7-JQHbKpyKfK95pgmt6rCTWC

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

